@@ -371,8 +371,13 @@ class Client(commandServer, encrypt):
             self.startTask(_("Applying non-domain templates"),progress=True)
         if self.clTempl:
             self.closeClTemplate()
+        self.clVars.Set('cl_autoupdate_set','on',True)
         self.clTempl = ProgressTemplate(self.setProgress,self.clVars,
-                                        cltObj=True)
+                                        cltObj=True,cltFilter=True,
+                                        printSUCCESS=self.printSUCCESS,
+                                        printERROR=self.printERROR,
+                                        askConfirm=self.askConfirm,
+                                        printWARNING=self.printWARNING)
         dirsFiles = self.clTempl.applyTemplates()
         if self.clTempl.getError():
             self.printERROR(self.clTempl.getError().strip())
@@ -1888,7 +1893,12 @@ class Client(commandServer, encrypt):
         if "." in domainName:
             domain = domainName
         else:
+            import socket
             domain = "%s.%s" %(domainName,netDomain)
+            try:
+                gethostbyname(domain)
+            except socket.gaierror as e:
+                domain = domainName
         # check domain by ping
         for i in range(0,1):
             try:
